# MediaWiki Revert Analysis

This library provides a set of utilities for detecting reverting activity in
MediaWiki projects.

* **Installation:** ``pip install mwreverts``
* **Documentation:** https://pythonhosted.org/mwreverts
* **License:** MIT

## Basic example

    >>>

## Author
* Aaron Halfaker -- https://github.com/halfak
